package com.waimai.web.admin.mapper;


import com.waimai.web.admin.domain.OrderFoods;

import java.util.List;

/**
 * 订单商品Mapper接口
 * 
 * @author callmeyan
 * @date 2023-03-24
 */
public interface OrderFoodsMapper 
{
    /**
     * 查询订单商品
     * 
     * @param id 订单商品主键
     * @return 订单商品
     */
    public OrderFoods selectOrderFoodsById(Long id);

    /**
     * 查询订单商品列表
     * 
     * @param orderFoods 订单商品
     * @return 订单商品集合
     */
    public List<OrderFoods> selectOrderFoodsList(OrderFoods orderFoods);

    /**
     * 新增订单商品
     * 
     * @param orderFoods 订单商品
     * @return 结果
     */
    public int insertOrderFoods(OrderFoods orderFoods);

    /**
     * 修改订单商品
     * 
     * @param orderFoods 订单商品
     * @return 结果
     */
    public int updateOrderFoods(OrderFoods orderFoods);

    /**
     * 删除订单商品
     * 
     * @param id 订单商品主键
     * @return 结果
     */
    public int deleteOrderFoodsById(Long id);

    /**
     * 批量删除订单商品
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteOrderFoodsByIds(Long[] ids);
}
